@@ -5,7 +5,7 @@
  *
  *  MathJax/localization/br/HTML-CSS.js
  *
- *  Copyright (c) 2009-2014 The MathJax Consortium
+ *  Copyright (c) 2009-2015 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -22,12 +22,14 @@
  */
 
 MathJax.Localization.addTranslation("br","HTML-CSS",{
-        version: "2.4.0",
+        version: "2.5.0",
         isLoaded: true,
         strings: {
           LoadWebFont: "O karga\u00F1 ar font web  %1",
           CantLoadWebFont: "Ne c'haller ket karga\u00F1 ar font web %1",
-          CantFindFontUsing: "Ne c'haller ket kavout ur font dereat e-touez %1"
+          CantFindFontUsing: "Ne c'haller ket kavout ur font dereat e-touez %1",
+          FirefoxCantLoadWebFont: "Ne c'hall ket Firefox karga\u00F1 ar fonto\u00F9 adalek un ostiz a-bell",
+          WebFontsNotAvailable: "N'haller ket kaout ar Fonto\u00F9 web. Ar fonto\u00F9 skeudenn a vo implijet en o flas"
         }
 });
 
