@@ -5,7 +5,7 @@
  *
  *  MathJax/localization/en/MathMenu.js
  *
- *  Copyright (c) 2009-2014 The MathJax Consortium
+ *  Copyright (c) 2009-2015 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -22,16 +22,16 @@
  */
 
 MathJax.Localization.addTranslation("en","MathMenu",{
-        version: "2.4.0",
+        version: "2.5.0",
         isLoaded: true,
         strings: {
-          Show: "Show Math As",
-          MathMLcode: "MathML Code",
+          Show: "Show math as",
+          MathMLcode: "MathML code",
           OriginalMathML: "Original MathML",
-          TeXCommands: "TeX Commands",
+          TeXCommands: "TeX commands",
           AsciiMathInput: "AsciiMathML input",
-          Original: "Original Form",
-          ErrorMessage: "Error Message",
+          Original: "Original form",
+          ErrorMessage: "Error message",
           Annotation: "Annotation",
           TeX: "TeX",
           StarMath: "StarMath",
@@ -39,25 +39,25 @@ MathJax.Localization.addTranslation("en","MathMenu",{
           ContentMathML: "Content MathML",
           OpenMath: "OpenMath",
           texHints: "Show TeX hints in MathML",
-          Settings: "Math Settings",
-          ZoomTrigger: "Zoom Trigger",
+          Settings: "Math settings",
+          ZoomTrigger: "Zoom trigger",
           Hover: "Hover",
           Click: "Click",
-          DoubleClick: "Double-Click",
-          NoZoom: "No Zoom",
-          TriggerRequires: "Trigger Requires:",
+          DoubleClick: "Double-click",
+          NoZoom: "No zoom",
+          TriggerRequires: "Trigger requires:",
           Option: "Option",
           Alt: "Alt",
           Command: "Command",
           Control: "Control",
           Shift: "Shift",
-          ZoomFactor: "Zoom Factor",
-          Renderer: "Math Renderer",
-          MPHandles: "Let MathPlayer Handle:",
-          MenuEvents: "Menu Events",
-          MouseEvents: "Mouse Events",
-          MenuAndMouse: "Mouse and Menu Events",
-          FontPrefs: "Font Preferences",
+          ZoomFactor: "Zoom factor",
+          Renderer: "Math renderer",
+          MPHandles: "Let MathPlayer handle:",
+          MenuEvents: "Menu events",
+          MouseEvents: "Mouse events",
+          MenuAndMouse: "Mouse and menu events",
+          FontPrefs: "Font preferences",
           ForHTMLCSS: "For HTML-CSS:",
           Auto: "Auto",
           TeXLocal: "TeX (local)",
@@ -70,36 +70,36 @@ MathJax.Localization.addTranslation("en","MathMenu",{
           GyreTermesWeb: "Gyre Termes (web)",
           LatinModernWeb: "Latin Modern (web)",
           NeoEulerWeb: "Neo Euler (web)",
-          ContextMenu: "Contextual Menu",
+          ContextMenu: "Contextual menu",
           Browser: "Browser",
-          Scale: "Scale All Math ...",
-          Discoverable: "Highlight on Hover",
+          Scale: "Scale all math ...",
+          Discoverable: "Highlight on hover",
           Locale: "Language",
           LoadLocale: "Load from URL ...",
           About: "About MathJax",
-          Help: "MathJax Help",
+          Help: "MathJax help",
           localTeXfonts: "using local TeX fonts",
           webTeXfonts: "using web TeX font",
           imagefonts: "using Image fonts",
           localSTIXfonts: "using local STIX fonts",
           webSVGfonts: "using web SVG fonts",
-          genericfonts: "using generic unicode fonts",
-          wofforotffonts: "woff or otf fonts",
-          eotffonts: "eot fonts",
-          svgfonts: "svg fonts",
-          WebkitNativeMMLWarning: "Your browser doesn't seem to support MathML natively, so switching to MathML output may cause the mathematics on the page to become unreadable.",
+          genericfonts: "using generic Unicode fonts",
+          wofforotffonts: "WOFF or OTF fonts",
+          eotffonts: "EOT fonts",
+          svgfonts: "SVG fonts",
+          WebkitNativeMMLWarning: "Your browser does not seem to support MathML natively, so switching to MathML output may cause the mathematics on the page to become unreadable",
           MSIENativeMMLWarning: "Internet Explorer requires the MathPlayer plugin in order to process MathML output.",
           OperaNativeMMLWarning: "Opera's support for MathML is limited, so switching to MathML output may cause some expressions to render poorly.",
           SafariNativeMMLWarning: "Your browser's native MathML does not implement all the features used by MathJax, so some expressions may not render properly.",
           FirefoxNativeMMLWarning: "Your browser's native MathML does not implement all the features used by MathJax, so some expressions may not render properly.",
           MSIESVGWarning: "SVG is not implemented in Internet Explorer prior to IE9 or when it is emulating IE8 or below. Switching to SVG output will cause the mathematics to not display properly.",
           LoadURL: "Load translation data from this URL:",
-          BadURL: "The URL should be for a javascript file that defines MathJax translation data.  Javascript file names should end with '.js'",
+          BadURL: "The URL should be for a JavaScript file that defines MathJax translation data. JavaScript file names should end with '.js'",
           BadData: "Failed to load translation data from %1",
           SwitchAnyway: "Switch the renderer anyway?\n\n(Press OK to switch, CANCEL to continue with the current renderer)",
           ScaleMath: "Scale all mathematics (compared to surrounding text) by",
           NonZeroScale: "The scale should not be zero",
-          PercentScale: "The scale should be a percentage (e.g., 120%%)",
+          PercentScale: "The scale should be a percentage (for example 120%%)",
           IE8warning: "This will disable the MathJax menu and zoom features, but you can Alt-Click on an expression to obtain the MathJax menu instead.\n\nReally change the MathPlayer settings?",
           IE9warning: "The MathJax contextual menu will be disabled, but you can Alt-Click on an expression to obtain the MathJax menu instead.",
           NoOriginalForm: "No original form available",
