@@ -5,7 +5,7 @@
  *
  *  MathJax/localization/en/en.js
  *
- *  Copyright (c) 2009-2014 The MathJax Consortium
+ *  Copyright (c) 2009-2015 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -23,22 +23,22 @@
 
 MathJax.Localization.addTranslation("en",null,{
   menuTitle: "English",
-  version: "2.4.0",
+  version: "2.5.0",
   isLoaded: true,
   domains: {
     "_": {
-        version: "2.4.0",
+        version: "2.5.0",
         isLoaded: true,
         strings: {
           CookieConfig: "MathJax has found a user-configuration cookie that includes code to be run. Do you want to run it?\n\n(You should press Cancel unless you set up the cookie yourself.)",
-          MathProcessingError: "Math Processing Error",
-          MathError: "Math Error",
+          MathProcessingError: "Math processing error",
+          MathError: "Math error",
           LoadFile: "Loading %1",
           Loading: "Loading",
           LoadFailed: "File failed to load: %1",
-          ProcessMath: "Processing Math: %1%%",
+          ProcessMath: "Processing math: %1%%",
           Processing: "Processing",
-          TypesetMath: "Typesetting Math: %1%%",
+          TypesetMath: "Typesetting math: %1%%",
           Typesetting: "Typesetting",
           MathJaxNotSupported: "Your browser does not support MathJax"
         }
