@@ -5,7 +5,7 @@
  *
  *  MathJax/localization/sv/HTML-CSS.js
  *
- *  Copyright (c) 2009-2013 The MathJax Consortium
+ *  Copyright (c) 2009-2015 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -22,11 +22,14 @@
  */
 
 MathJax.Localization.addTranslation("sv","HTML-CSS",{
-        version: "2.3",
+        version: "2.5.0",
         isLoaded: true,
         strings: {
-          FirefoxCantLoadWebFont: "Firefox kan inte l\u00E4sa in webbteckensnitt fr\u00E5n en fj\u00E4rrstyrd v\u00E4rd",
-          CantFindFontUsing: "Kan inte hitta ett giltigt teckensnitt med %1"
+          LoadWebFont: "L\u00E4ser in webbtypsnittet %1",
+          CantLoadWebFont: "Kan inte l\u00E4sa in webbtypsnittet %1",
+          FirefoxCantLoadWebFont: "Firefox kan inte l\u00E4sa in webbteckensnitt fr\u00E5n en fj\u00E4rrv\u00E4rd",
+          CantFindFontUsing: "Kan inte hitta ett giltigt teckensnitt med hj\u00E4lp av %1",
+          WebFontsNotAvailable: "Webbtypsnitt \u00E4r inte tillg\u00E4ngliga. Anv\u00E4nder bildtypsnitt ist\u00E4llet"
         }
 });
 
